#include <SPI.h>
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>
#define SCREEN_WIDTH 128 // OLED display width, in pixels
#define SCREEN_HEIGHT 64 // OLED display height, in pixels
#define OLED_RESET     -1 // Reset pin # (or -1 if sharing Arduino reset pin)
#define SCREEN_ADDRESS 0x3C ///< See datasheet for Address; 0x3D for 128x64, 0x3C for 128x32
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);



const int numThermistors = 6;
const int analogPins[numThermistors] = {A0, A1, A2, A3, A6, A7};
const float pullUpResistance = 4700.0; // 10k ohm
const float referenceResistance = 100000.0; // 100k ohm at 25°C
const float betaCoefficient = 3950.0; // Beta coefficient for the NTC thermistor
const float nominalTemperature = 30.5; // Nominal temperature for the NTC thermistor in °C

void setup() {
  Serial.begin(9600);
  // SSD1306_SWITCHCAPVCC = generate display voltage from 3.3V internally
  if(!display.begin(SSD1306_SWITCHCAPVCC, SCREEN_ADDRESS)) {
    Serial.println(F("SSD1306 allocation failed"));
    for(;;); // Don't proceed, loop forever
}
  display.clearDisplay();
  display.setTextColor(WHITE);
  }

void loop() {
   display.clearDisplay();
  for (int i = 0; i < numThermistors; i++) {
    float rawReading = analogRead(analogPins[i]);
    float resistance = pullUpResistance / (1023.0 / rawReading - 1.0);
    float temperature = 1.0 / ((1.0 / (nominalTemperature + 273.15)) + (1.0 / betaCoefficient) * log(resistance / referenceResistance)) - 273.15;

  display.setTextSize(1);
  display.setCursor(22,i * 10);
    display.print("T ");
    display.print(i);
    display.print(": ");
    display.print(temperature);
    display.println(".C");
    
  }
display.display(); 
  delay(300); // Delay for 1 second before reading again
}
